Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/optwps/__init__.py | (no function) | 8 | 2 | 0 | 0 | 0 | 75%
src/optwps/optwps.py | ROIGenerator.__init__ | 2 | 0 | 0 | 0 | 0 | 100%
src/optwps/optwps.py | ROIGenerator.regions | 23 | 0 | 0 | 10 | 0 | 100%
src/optwps/optwps.py | CMWriterUnpacker.__init__ | 5 | 2 | 0 | 0 | 0 | 60%
src/optwps/optwps.py | CMWriterUnpacker.write | 1 | 0 | 0 | 0 | 0 | 100%
src/optwps/optwps.py | CMWriterUnpacker.close | 5 | 0 | 0 | 2 | 0 | 100%
src/optwps/optwps.py | WPS.__init__ | 9 | 1 | 0 | 2 | 1 | 82%
src/optwps/optwps.py | WPS.__call__ | 1 | 1 | 0 | 0 | 0 | 0%
src/optwps/optwps.py | WPS.run | 114 | 8 | 0 | 52 | 7 | 91%
src/optwps/optwps.py | main | 19 | 19 | 0 | 2 | 0 | 0%
src/optwps/optwps.py | (no function) | 22 | 1 | 0 | 2 | 1 | 92%
src/optwps/utils.py | is_soft_clipped | 1 | 0 | 0 | 0 | 0 | 100%
src/optwps/utils.py | ref_aln_length | 1 | 0 | 0 | 0 | 0 | 100%
src/optwps/utils.py | exopen | 12 | 2 | 0 | 6 | 1 | 83%
src/optwps/utils.py | (no function) | 9 | 0 | 0 | 0 | 0 | 100%
tests/__init__.py | (no function) | 0 | 0 | 0 | 0 | 0 | 100%
tests/conftest.py | make_test_bed_file | 4 | 0 | 0 | 0 | 0 | 100%
tests/conftest.py | _create_read | 14 | 0 | 0 | 2 | 0 | 100%
tests/conftest.py | make_test_bam_file_paired | 21 | 0 | 0 | 2 | 0 | 100%
tests/conftest.py | make_test_bam_file_single | 15 | 0 | 0 | 2 | 0 | 100%
tests/conftest.py | (no function) | 9 | 0 | 0 | 0 | 0 | 100%
tests/test_multiple_outputs.py | test_multiple_outputs_with_chrom_placeholder | 13 | 0 | 0 | 4 | 0 | 100%
tests/test_multiple_outputs.py | test_multiple_outputs_with_target_placeholder | 26 | 0 | 0 | 6 | 0 | 100%
tests/test_multiple_outputs.py | test_multiple_outputs_with_both_placeholders | 11 | 0 | 0 | 2 | 0 | 100%
tests/test_multiple_outputs.py | test_multiple_outputs_handles_chunking | 11 | 0 | 0 | 4 | 1 | 93%
tests/test_multiple_outputs.py | test_single_output_still_works | 8 | 0 | 0 | 0 | 0 | 100%
tests/test_multiple_outputs.py | test_multiple_outputs_with_gzip | 10 | 0 | 0 | 2 | 0 | 100%
tests/test_multiple_outputs.py | (no function) | 7 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | old_implementation | 53 | 7 | 0 | 36 | 9 | 82%
tests/test_optwps.py | test_optwps_does_the_same_as_old_version_paired_end | 14 | 1 | 0 | 4 | 1 | 89%
tests/test_optwps.py | test_optwps_does_the_same_as_old_version_single_end | 14 | 1 | 0 | 4 | 1 | 89%
tests/test_optwps.py | test_optwps_downsampling | 10 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | test_optwps_no_bed_file | 7 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | test_gzbedfile_handling | 10 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | test_with_minsize_maxsize | 10 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | test_with_coverage_computation | 8 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | test_printed_to_stdout | 9 | 0 | 0 | 2 | 0 | 100%
tests/test_optwps.py | (no function) | 12 | 0 | 0 | 0 | 0 | 100%
Total |  | 528 | 45 | 0 | 146 | 22 | 90%

No items found using the specified filter.